


Related Software
----------------

- pyCO2sys `https://pyco2sys.readthedocs.io/en/latest/ <https://pyco2sys.readthedocs.io/en/latest/>`_

- A Python based LOSCAR implementation `https://github.com/Shihan150/iloscar <https://github.com/Shihan150/iloscar>`_
